@@ -102,7 +102,7 @@ function configure_zaqar {
 
     configure_auth_token_middleware $ZAQAR_CONF zaqar $ZAQAR_AUTH_CACHE_DIR
 
-    iniset $ZAQAR_CONF trustee auth_plugin password
+    iniset $ZAQAR_CONF trustee auth_type password
     iniset $ZAQAR_CONF trustee auth_url $KEYSTONE_AUTH_URI
     iniset $ZAQAR_CONF trustee username $ZAQAR_TRUSTEE_USER
     iniset $ZAQAR_CONF trustee password $ZAQAR_TRUSTEE_PASSWORD
@@ -129,6 +129,8 @@ function configure_zaqar {
         iniset $ZAQAR_CONF 'drivers:management_store:sqlalchemy' uri `database_connection_url zaqar`
         iniset $ZAQAR_CONF 'drivers:management_store:sqlalchemy' database zaqar_mgmt
 
+        zaqar-sql-db-manage --config-file $ZAQAR_CONF upgrade head
+
         iniset $ZAQAR_CONF  drivers message_store redis
         iniset $ZAQAR_CONF 'drivers:message_store:redis' uri redis://localhost:6379
         iniset $ZAQAR_CONF 'drivers:message_store:redis' database zaqar
@@ -139,6 +141,8 @@ function configure_zaqar {
         iniset $ZAQAR_CONF 'drivers:management_store:sqlalchemy' uri `database_connection_url zaqar`
         iniset $ZAQAR_CONF 'drivers:management_store:sqlalchemy' database zaqar_mgmt
 
+        zaqar-sql-db-manage --config-file $ZAQAR_CONF upgrade head
+
         iniset $ZAQAR_CONF  drivers message_store swift
         iniset $ZAQAR_CONF 'drivers:message_store:swift' auth_url $KEYSTONE_AUTH_URI_V3
         iniset $ZAQAR_CONF 'drivers:message_store:swift' uri swift://zaqar:$SERVICE_PASSWORD@/service
@@ -151,14 +155,20 @@ function configure_zaqar {
     iniset_rpc_backend zaqar $ZAQAR_CONF DEFAULT
 
     pip_install uwsgi
+
+    iniset $ZAQAR_UWSGI_CONF uwsgi master true
+    iniset $ZAQAR_UWSGI_CONF uwsgi die-on-term true
+    iniset $ZAQAR_UWSGI_CONF uwsgi exit-on-reload true
     iniset $ZAQAR_UWSGI_CONF uwsgi http $ZAQAR_SERVICE_HOST:$ZAQAR_SERVICE_PORT
-    iniset $ZAQAR_UWSGI_CONF uwsgi harakiri 60
-    iniset $ZAQAR_UWSGI_CONF uwsgi processes 1
+    iniset $ZAQAR_UWSGI_CONF uwsgi processes $API_WORKERS
+    iniset $ZAQAR_UWSGI_CONF uwsgi enable_threads true
     iniset $ZAQAR_UWSGI_CONF uwsgi threads 4
+    iniset $ZAQAR_UWSGI_CONF uwsgi thunder-lock true
+    iniset $ZAQAR_UWSGI_CONF uwsgi buffer-size 65535
     iniset $ZAQAR_UWSGI_CONF uwsgi wsgi-file $ZAQAR_DIR/zaqar/transport/wsgi/app.py
-    iniset $ZAQAR_UWSGI_CONF uwsgi callable app
     iniset $ZAQAR_UWSGI_CONF uwsgi master true
     iniset $ZAQAR_UWSGI_CONF uwsgi add-header "Connection: close"
+    iniset $ZAQAR_UWSGI_CONF uwsgi lazy-apps true
 
     cleanup_zaqar
 }
@@ -218,9 +228,8 @@ function install_zaqarui {
     # Remove following two 'mv' commands when mentioned bug is fixed.
     mv $ZAQARUI_DIR/test-requirements.txt $ZAQARUI_DIR/_test-requirements.txt
     setup_develop $ZAQARUI_DIR
-    mv $ZAQARUI_DIR/_test-requirements.txt $ZAQARUI_DIR/test-requirements.txt
-    ln -fs $ZAQARUI_DIR/zaqar_ui/enabled/_1510_project_messaging_group.py $HORIZON_DIR/openstack_dashboard/local/enabled/_1510_project_messaging_group.py
-    ln -fs $ZAQARUI_DIR/zaqar_ui/enabled/_1520_project_queues.py $HORIZON_DIR/openstack_dashboard/local/enabled/_1520_project_queues.py
+    mv $ZAQARUI_DIR/_test-requirements.txt $ZAQARUI_DIR/test-requirements.txt   
+    cp -a $ZAQARUI_DIR/zaqar_ui/enabled/* $HORIZON_DIR/openstack_dashboard/local/enabled/
     if [ -d $ZAQARUI_DIR/zaqar-ui/locale ]; then
         (cd $ZAQARUI_DIR/zaqar-ui; DJANGO_SETTINGS_MODULE=openstack_dashboard.settings ../manage.py compilemessages)
     fi
@@ -238,8 +247,14 @@ function install_zaqarclient {
 # start_zaqar() - Start running processes, including screen
 function start_zaqar {
     cat $ZAQAR_UWSGI_CONF
-    run_process zaqar-wsgi "uwsgi --ini $ZAQAR_UWSGI_CONF --pidfile2 $ZAQAR_UWSGI_MASTER_PIDFILE"
-    run_process zaqar-websocket "zaqar-server --config-file $ZAQAR_CONF"
+    run_process zaqar-wsgi "$ZAQAR_BIN_DIR/uwsgi --ini $ZAQAR_UWSGI_CONF --pidfile2 $ZAQAR_UWSGI_MASTER_PIDFILE"
+    run_process zaqar-websocket "$ZAQAR_BIN_DIR/zaqar-server --config-file $ZAQAR_CONF"
+
+    echo "Waiting for Zaqar to start..."
+    token=$(openstack token issue -c id -f value)
+    if ! timeout $SERVICE_TIMEOUT sh -c "while ! wget --no-proxy -q --header=\"Client-ID:$(uuidgen)\" --header=\"X-Auth-Token:$token\" -O- $ZAQAR_SERVICE_PROTOCOL://$ZAQAR_SERVICE_HOST:$ZAQAR_SERVICE_PORT/v2/ping; do sleep 1; done"; then
+        die $LINENO "Zaqar did not start"
+    fi
 }
 
 # stop_zaqar() - Stop running processes
