@@ -19,11 +19,11 @@
 import abc
 import functools
 import time
-import uuid
 
 import enum
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import uuidutils
 import six
 
 from zaqar.common import decorators
@@ -59,7 +59,7 @@ class DriverBase(object):
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
+    :type cache: `dogpile.cache.region.CacheRegion`
     """
     _DRIVER_OPTIONS = []
 
@@ -91,7 +91,7 @@ class DataDriverBase(DriverBase):
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
+    :type cache: `dogpile.cache.region.CacheRegion`
     """
 
     BASE_CAPABILITIES = []
@@ -138,9 +138,9 @@ class DataDriverBase(DriverBase):
         status_template = lambda s, t, r: {'succeeded': s,
                                            'seconds': t,
                                            'ref': r}
-        project = str(uuid.uuid4())
-        queue = str(uuid.uuid4())
-        client = str(uuid.uuid4())
+        project = uuidutils.generate_uuid()
+        queue = uuidutils.generate_uuid()
+        client = uuidutils.generate_uuid()
         msg_template = lambda s: {'ttl': 600, 'body': {'event': 'p_%s' % s}}
         messages = [msg_template(i) for i in range(100)]
         claim_metadata = {'ttl': 60, 'grace': 300}
@@ -155,7 +155,7 @@ class DataDriverBase(DriverBase):
                 start = time.time()
                 result = callable_operation()
             except Exception as e:
-                ref = str(uuid.uuid4())
+                ref = uuidutils.generate_uuid()
                 LOG.exception(e, extra={'instance_uuid': ref})
                 succeeded = False
             status = status_template(succeeded, time.time() - start, ref)
@@ -258,7 +258,7 @@ class ControlDriverBase(DriverBase):
     :type conf: `oslo_config.ConfigOpts`
     :param cache: Cache instance to use for reducing latency
         for certain lookups.
-    :type cache: `zaqar.openstack.common.cache.backends.BaseCache`
+    :type cache: `dogpile.cache.region.CacheRegion`
     """
 
     @abc.abstractproperty
@@ -332,7 +332,7 @@ class Queue(ControllerBase):
         :param project: Project id
 
         :returns: Dictionary containing queue metadata
-        :raises: DoesNotExist
+        :raises DoesNotExist: if queue metadata does not exist
         """
         return self._get(name, project)
 
@@ -345,7 +345,7 @@ class Queue(ControllerBase):
         :param project: Project id
 
         :returns: Dictionary containing queue metadata
-        :raises: DoesNotExist
+        :raises DoesNotExist: if queue metadata does not exist
         """
         raise NotImplementedError
 
@@ -355,7 +355,7 @@ class Queue(ControllerBase):
         :param name: The queue name
         :param metadata: Queue metadata as a dict
         :param project: Project id
-        :raises: DoesNotExist
+        :raises DoesNotExist: if queue metadata can not be updated
         """
         raise NotImplementedError
 
@@ -458,7 +458,7 @@ class Message(ControllerBase):
         :param message_id: Message ID
 
         :returns: Dictionary containing message data
-        :raises: DoesNotExist
+        :raises DoesNotExist: if message data can not be got
         """
         raise NotImplementedError
 
@@ -547,7 +547,7 @@ class Claim(ControllerBase):
         :param project: Project id
 
         :returns: (Claim's metadata, claimed messages)
-        :raises: DoesNotExist
+        :raises DoesNotExist: if claimed messages can not be got
         """
         raise NotImplementedError
 
@@ -630,7 +630,7 @@ class Subscription(ControllerBase):
         :type project: six.text_type
         :returns: Dictionary containing subscription data
         :rtype: {}
-        :raises: SubscriptionDoesNotExist if not found
+        :raises SubscriptionDoesNotExist: if not found
         """
         raise NotImplementedError
 
@@ -664,7 +664,9 @@ class Subscription(ControllerBase):
         :type name: text
         :param kwargs: one of: `source`, `subscriber`, `ttl`, `options`
         :type kwargs: dict
-        :raises: SubscriptionDoesNotExist if not found
+        :raises SubscriptionDoesNotExist: if not found
+        :raises SubscriptionAlreadyExists: if attempt to update in a way to
+            create duplicate subscription
         """
 
         raise NotImplementedError
@@ -697,6 +699,37 @@ class Subscription(ControllerBase):
         """
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def get_with_subscriber(self, queue, subscriber, project=None):
+        """Base method for get a subscription with the subscriber.
+
+        :param queue: Name of the queue subscription belongs to.
+        :type queue: six.text_type
+        :param subscriber: link of the subscription to be notified.
+        :type subscriber: six.text_type
+        :param project: Project id
+        :type project: six.text_type
+        :returns: Dictionary containing subscription data
+        :rtype: dict
+        """
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def confirm(self, queue, subscription_id, project=None, confirmed=True):
+        """Base method for confirming a subscription.
+
+        :param queue: Name of the queue subscription belongs to.
+        :type queue: six.text_type
+        :param subscription_id: ID of the subscription to be deleted.
+        :type subscription_id: six.text_type
+        :param project: Project id
+        :type project: six.text_type
+        :param confirmed: Confirm a subscription or cancel the confirmation of
+            a subscription.
+        :type confirmed: boolean
+        """
+        raise NotImplementedError
+
 
 @six.add_metaclass(abc.ABCMeta)
 class PoolsBase(ControllerBase):
@@ -726,9 +759,9 @@ class PoolsBase(ControllerBase):
         :type name: six.text_type
         """
         if name:
-            group = list(self._get_group(self._get(name)['group']))
+            group = list(self._get_pools_by_group(self._get(name)['group']))
         else:
-            group = list(self._get_group(group))
+            group = list(self._get_pools_by_group(group))
 
         if not len(group) > 0:
             return ()
@@ -780,21 +813,21 @@ class PoolsBase(ControllerBase):
 
     _create = abc.abstractmethod(lambda x: None)
 
-    def get_group(self, group=None, detailed=False):
-        """Returns a single pool entry.
+    def get_pools_by_group(self, group=None, detailed=False):
+        """Returns a pool list filtered by given pool group.
 
         :param group: The group to filter on. `None` returns
-            pools that are not assigned to any pool.
+            pools that are not assigned to any pool group.
         :type group: six.text_type
         :param detailed: Should the options data be included?
         :type detailed: bool
         :returns: weight, uri, and options for this pool
         :rtype: {}
-        :raises: PoolDoesNotExist if not found
+        :raises PoolDoesNotExist: if not found
         """
-        return self._get_group(group, detailed)
+        return self._get_pools_by_group(group, detailed)
 
-    _get_group = abc.abstractmethod(lambda x: None)
+    _get_pools_by_group = abc.abstractmethod(lambda x: None)
 
     def get(self, name, detailed=False):
         """Returns a single pool entry.
@@ -805,7 +838,7 @@ class PoolsBase(ControllerBase):
         :type detailed: bool
         :returns: weight, uri, and options for this pool
         :rtype: {}
-        :raises: PoolDoesNotExist if not found
+        :raises PoolDoesNotExist: if not found
         """
         return self._get(name, detailed)
 
@@ -841,7 +874,7 @@ class PoolsBase(ControllerBase):
         :type name: text
         :param kwargs: one of: `uri`, `weight`, `options`
         :type kwargs: dict
-        :raises: PoolDoesNotExist
+        :raises PoolDoesNotExist: if not found
         """
         uri = kwargs.get('uri')
         if uri and not self._check_capabilities(uri, name=name):
@@ -889,7 +922,7 @@ class CatalogueBase(ControllerBase):
         :type queue: six.text_type
         :returns: {'pool': ...}
         :rtype: dict
-        :raises: QueueNotMapped
+        :raises QueueNotMapped: if queue is not mapped
         """
 
         raise NotImplementedError
@@ -942,7 +975,7 @@ class CatalogueBase(ControllerBase):
         :type queue: six.text_type
         :param pools: The name of the pool where this project/queue lives.
         :type pools: six.text_type
-        :raises: QueueNotMapped
+        :raises QueueNotMapped: if queue is not mapped
         """
 
         raise NotImplementedError
@@ -999,7 +1032,7 @@ class FlavorsBase(ControllerBase):
         :param project: Project this flavor belongs to.
         :type project: six.text_type
         :rtype: {}
-        :raises: FlavorDoesNotExist if not found
+        :raises FlavorDoesNotExist: if not found
         """
 
         raise NotImplementedError
@@ -1041,7 +1074,7 @@ class FlavorsBase(ControllerBase):
         :type project: six.text_type
         :param kwargs: one of: `uri`, `weight`, `options`
         :type kwargs: dict
-        :raises: FlavorDoesNotExist
+        :raises FlavorDoesNotExist: if not found
         """
 
         raise NotImplementedError
