@@ -31,7 +31,6 @@ import pymongo.errors
 import pymongo.read_preferences
 
 from zaqar.i18n import _
-from zaqar.i18n import _LW
 from zaqar import storage
 from zaqar.storage import errors
 from zaqar.storage.mongodb import utils
@@ -227,7 +226,7 @@ class MessageController(storage.Message):
         """
         scope = utils.scope_queue_name(queue_name, project)
         collection = self._collection(queue_name, project)
-        collection.remove({PROJ_QUEUE: scope}, w=0)
+        collection.delete_many({PROJ_QUEUE: scope})
 
     def _list(self, queue_name, project=None, marker=None,
               echo=False, client_uuid=None, projection=None,
@@ -244,8 +243,9 @@ class MessageController(storage.Message):
             client_uuid
         :param client_uuid: (Default None) UUID for the client that
             originated this request
-        :param fields: (Default None) Fields to include in emitted
-            documents
+        :param projection: (Default None) a list of field names that should be
+            returned in the result set or a dict specifying the fields to
+            include or exclude
         :param include_claimed: (Default False) Whether to include
             claimed messages, not just active ones
         :param sort: (Default 1) Sort order for the listing. Pass 1 for
@@ -396,9 +396,9 @@ class MessageController(storage.Message):
         scope = utils.scope_queue_name(queue_name, project)
         collection = self._collection(queue_name, project)
 
-        collection.update({PROJ_QUEUE: scope, 'c.id': cid},
-                          {'$set': {'c': {'id': None, 'e': now}}},
-                          upsert=False, multi=True)
+        collection.update_many({PROJ_QUEUE: scope, 'c.id': cid},
+                               {'$set': {'c': {'id': None, 'e': now}}},
+                               upsert=False)
 
     def _inc_counter(self, queue_name, project=None, amount=1, window=None):
         """Increments the message counter and returns the new value.
@@ -414,7 +414,7 @@ class MessageController(storage.Message):
             was specified, and the counter has already been updated
             within the specified time period.
 
-        :raises: storage.errors.QueueDoesNotExist
+        :raises QueueDoesNotExist: if not found
         """
 
         # NOTE(flaper87): If this `if` is True, it means we're
@@ -451,9 +451,9 @@ class MessageController(storage.Message):
                 # NOTE(kgriffs): Since we did not filter by a time window,
                 # the queue should have been found and updated. Perhaps
                 # the queue has been deleted?
-                message = _LW(u'Failed to increment the message '
-                              u'counter for queue %(name)s and '
-                              u'project %(project)s')
+                message = (u'Failed to increment the message '
+                           u'counter for queue %(name)s and '
+                           u'project %(project)s')
                 message %= dict(name=queue_name, project=project)
 
                 LOG.warning(message)
@@ -637,7 +637,7 @@ class MessageController(storage.Message):
                 't': message['ttl'],
                 'e': now_dt + datetime.timedelta(seconds=message['ttl']),
                 'u': client_uuid,
-                'c': {'id': None, 'e': now},
+                'c': {'id': None, 'e': now, 'c': 0},
                 'b': message['body'] if 'body' in message else {},
                 'k': next_marker + index,
                 'tx': None,
@@ -699,7 +699,7 @@ class MessageController(storage.Message):
 
                     raise errors.MessageNotClaimed(message_id)
 
-        collection.remove(query['_id'], w=0)
+        collection.delete_one(query)
 
     @utils.raises_conn_error
     @utils.retries_on_autoreconnect
@@ -711,7 +711,7 @@ class MessageController(storage.Message):
         }
 
         collection = self._collection(queue_name, project)
-        collection.remove(query, w=0)
+        collection.delete_many(query)
 
     @utils.raises_conn_error
     @utils.retries_on_autoreconnect
@@ -728,9 +728,8 @@ class MessageController(storage.Message):
         collection = self._collection(queue_name, project)
         projection = {'_id': 1, 't': 1, 'b': 1, 'c.id': 1}
 
-        messages = (collection.find_and_modify(query,
-                                               projection=projection,
-                                               remove=True)
+        messages = (collection.find_one_and_delete(query,
+                                                   projection=projection)
                     for _ in range(limit))
 
         final_messages = [_basic_message(message, now)
@@ -815,7 +814,7 @@ class FIFOMessageController(MessageController):
                 't': message['ttl'],
                 'e': now_dt + datetime.timedelta(seconds=message['ttl']),
                 'u': client_uuid,
-                'c': {'id': None, 'e': now},
+                'c': {'id': None, 'e': now, 'c': 0},
                 'b': message['body'] if 'body' in message else {},
                 'k': next_marker + index,
                 'tx': transaction,
@@ -868,9 +867,9 @@ class FIFOMessageController(MessageController):
                 # atomic, assuming queries filter out any non-finalized
                 # messages.
                 if transaction is not None:
-                    collection.update({'tx': transaction},
-                                      {'$set': {'tx': None}},
-                                      upsert=False, multi=True)
+                    collection.update_many({'tx': transaction},
+                                           {'$set': {'tx': None}},
+                                           upsert=False)
 
                 return [str(id_) for id_ in ids]
 
@@ -900,8 +899,8 @@ class FIFOMessageController(MessageController):
                 # this situation can not happen.
                 elapsed = timeutils.utcnow_ts() - now
                 if elapsed > MAX_RETRY_POST_DURATION:
-                    msgtmpl = _LW(u'Exceeded maximum retry duration for queue '
-                                  u'"%(queue)s" under project %(project)s')
+                    msgtmpl = (u'Exceeded maximum retry duration for queue '
+                               u'"%(queue)s" under project %(project)s')
 
                     LOG.warning(msgtmpl,
                                 dict(queue=queue_name, project=project))
@@ -944,10 +943,10 @@ class FIFOMessageController(MessageController):
                     next_marker = self._get_counter(
                         queue_name, project)
                 else:
-                    msgtmpl = _LW(u'Detected a stalled message counter '
-                                  u'for queue "%(queue)s" under '
-                                  u'project %(project)s.'
-                                  u'The counter was incremented to %(value)d.')
+                    msgtmpl = (u'Detected a stalled message counter '
+                               u'for queue "%(queue)s" under '
+                               u'project %(project)s.'
+                               u'The counter was incremented to %(value)d.')
 
                     LOG.warning(msgtmpl,
                                 dict(queue=queue_name,
@@ -961,8 +960,8 @@ class FIFOMessageController(MessageController):
                 LOG.exception(ex)
                 raise
 
-        msgtmpl = _LW(u'Hit maximum number of attempts (%(max)s) for queue '
-                      u'"%(queue)s" under project %(project)s')
+        msgtmpl = (u'Hit maximum number of attempts (%(max)s) for queue '
+                   u'"%(queue)s" under project %(project)s')
 
         LOG.warning(msgtmpl,
                     dict(max=self.driver.mongodb_conf.max_attempts,
