@@ -13,10 +13,10 @@
 # the License.
 
 import functools
-import uuid
 
 import msgpack
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 import redis
 
 from zaqar.common import utils as common_utils
@@ -106,7 +106,7 @@ class SubscriptionController(base.Subscription):
     @utils.raises_conn_error
     @utils.retries_on_connection_error
     def create(self, queue, subscriber, ttl, options, project=None):
-        subscription_id = str(uuid.uuid4())
+        subscription_id = uuidutils.generate_uuid()
         subset_key = utils.scope_subscription_ids_set(queue,
                                                       project,
                                                       SUBSCRIPTION_IDS_SUFFIX)
@@ -196,7 +196,7 @@ class SubscriptionController(base.Subscription):
         subscription_to_update = self.get(queue, subscription_id,
                                           project=project)
 
-        new_subscriber = fields.get('u', None)
+        new_subscriber = fields.get('u')
 
         # Let's do some checks to prevent subscription duplication.
         if new_subscriber:
@@ -210,11 +210,11 @@ class SubscriptionController(base.Subscription):
 
         # NOTE(Eva-i): if there are new options, we need to pack them before
         # sending to the database.
-        new_options = fields.get('o', None)
+        new_options = fields.get('o')
         if new_options is not None:
             fields['o'] = self._packer(new_options)
 
-        new_ttl = fields.get('t', None)
+        new_ttl = fields.get('t')
         if new_ttl is not None:
             now = timeutils.utcnow_ts()
             expires = now + new_ttl
