@@ -19,6 +19,7 @@ controller for sqlalchemy.
 
 import functools
 
+import oslo_db.exception
 import sqlalchemy as sa
 
 from zaqar.common import utils as common_utils
@@ -42,7 +43,7 @@ class PoolsController(base.PoolsBase):
         )
         if limit > 0:
             stmt = stmt.limit(limit)
-        cursor = self.driver.connection.execute(stmt)
+        cursor = self.driver.run(stmt)
 
         marker_name = {}
 
@@ -55,11 +56,11 @@ class PoolsController(base.PoolsBase):
         yield marker_name and marker_name['next']
 
     @utils.raises_conn_error
-    def _get_group(self, group=None, detailed=False):
+    def _get_pools_by_group(self, group=None, detailed=False):
         stmt = sa.sql.select([tables.Pools]).where(
             tables.Pools.c.group == group
         )
-        cursor = self.driver.connection.execute(stmt)
+        cursor = self.driver.run(stmt)
 
         normalizer = functools.partial(_normalize, detailed=detailed)
         return (normalizer(v) for v in cursor)
@@ -70,7 +71,7 @@ class PoolsController(base.PoolsBase):
             tables.Pools.c.name == name
         )
 
-        pool = self.driver.connection.execute(stmt).fetchone()
+        pool = self.driver.run(stmt).fetchone()
         if pool is None:
             raise errors.PoolDoesNotExist(name)
 
@@ -79,9 +80,9 @@ class PoolsController(base.PoolsBase):
     def _ensure_group_exists(self, name):
         try:
             stmt = sa.sql.expression.insert(tables.PoolGroup).values(name=name)
-            self.driver.connection.execute(stmt)
+            self.driver.run(stmt)
             return True
-        except sa.exc.IntegrityError:
+        except oslo_db.exception.DBDuplicateEntry:
             return False
 
     # TODO(cpp-cabrera): rename to upsert
@@ -96,9 +97,9 @@ class PoolsController(base.PoolsBase):
             stmt = sa.sql.expression.insert(tables.Pools).values(
                 name=name, weight=weight, uri=uri, group=group, options=opts
             )
-            self.driver.connection.execute(stmt)
+            self.driver.run(stmt)
 
-        except sa.exc.IntegrityError:
+        except oslo_db.exception.DBDuplicateEntry:
             # TODO(cpp-cabrera): merge update/create into a single
             # method with introduction of upsert
             self._update(name, weight=weight, uri=uri,
@@ -109,7 +110,7 @@ class PoolsController(base.PoolsBase):
         stmt = sa.sql.select([tables.Pools.c.name]).where(
             tables.Pools.c.name == name
         ).limit(1)
-        return self.driver.connection.execute(stmt).fetchone() is not None
+        return self.driver.run(stmt).fetchone() is not None
 
     @utils.raises_conn_error
     def _update(self, name, **kwargs):
@@ -132,7 +133,7 @@ class PoolsController(base.PoolsBase):
         stmt = sa.sql.update(tables.Pools).where(
             tables.Pools.c.name == name).values(**fields)
 
-        res = self.driver.connection.execute(stmt)
+        res = self.driver.run(stmt)
         if res.rowcount == 0:
             raise errors.PoolDoesNotExist(name)
 
@@ -141,14 +142,14 @@ class PoolsController(base.PoolsBase):
         stmt = sa.sql.expression.delete(tables.Pools).where(
             tables.Pools.c.name == name
         )
-        self.driver.connection.execute(stmt)
+        self.driver.run(stmt)
 
     @utils.raises_conn_error
     def _drop_all(self):
         stmt = sa.sql.expression.delete(tables.Pools)
-        self.driver.connection.execute(stmt)
+        self.driver.run(stmt)
         stmt = sa.sql.expression.delete(tables.PoolGroup)
-        self.driver.connection.execute(stmt)
+        self.driver.run(stmt)
 
 
 def _normalize(pool, detailed=False):
