@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
+from oslo_utils import uuidutils
 
 from oslo_serialization import jsonutils as json
 from six.moves.urllib import parse as urllib
@@ -36,7 +36,7 @@ class MessagingClient(rest_client.RestClient):
         self.version = '1'
         self.uri_prefix = 'v{0}'.format(self.version)
 
-        client_id = uuid.uuid4().hex
+        client_id = uuidutils.generate_uuid(dashed=False)
         self.headers = {'Client-ID': client_id}
 
 
@@ -187,9 +187,6 @@ class V11MessagingClient(MessagingClient):
         self.version = '1.1'
         self.uri_prefix = 'v{0}'.format(self.version)
 
-        client_id = uuid.uuid4().hex
-        self.headers = {'Client-ID': client_id}
-
     def list_queues(self):
         uri = '{0}/queues'.format(self.uri_prefix)
         resp, body = self.get(uri, headers=self.headers)
@@ -326,9 +323,6 @@ class V2MessagingClient(MessagingClient):
         self.version = '2'
         self.uri_prefix = 'v{0}'.format(self.version)
 
-        client_id = uuid.uuid4().hex
-        self.headers = {'Client-ID': client_id}
-
     def list_queues(self, url_params=False):
         uri = '{0}/queues'.format(self.uri_prefix)
         if url_params:
@@ -376,17 +370,20 @@ class V2MessagingClient(MessagingClient):
         return resp, body
 
     def show_queue_metadata(self, queue_name):
-        uri = '{0}/queues/{1}/metadata'.format(self.uri_prefix, queue_name)
+        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
         resp, body = self.get(uri, headers=self.headers)
         self.expected_success(200, resp.status)
         body = json.loads(body)
         return resp, body
 
     def set_queue_metadata(self, queue_name, rbody):
-        uri = '{0}/queues/{1}/metadata'.format(self.uri_prefix, queue_name)
-        resp, body = self.put(uri, body=json.dumps(rbody),
-                              headers=self.headers)
-        self.expected_success(204, resp.status)
+        uri = '{0}/queues/{1}'.format(self.uri_prefix, queue_name)
+        headers = self.headers.copy()
+        headers['Content-Type'] =\
+            'application/openstack-messaging-v2.0-json-patch'
+        resp, body = self.patch(uri, body=json.dumps(rbody),
+                                headers=headers)
+        self.expected_success(200, resp.status)
         return resp, body
 
     def post_messages(self, queue_name, rbody):
@@ -445,8 +442,9 @@ class V2MessagingClient(MessagingClient):
                                extra_headers=True,
                                headers=self.headers)
 
-        body = json.loads(body)
-        self.validate_response(v2schema.claim_messages, resp, body)
+        if resp['status'] != '204':
+            body = json.loads(body)
+            self.validate_response(v2schema.claim_messages, resp, body)
         return resp, body
 
     def query_claim(self, claim_uri):
