@@ -14,11 +14,11 @@
 # limitations under the License.
 
 import json
-import uuid
 
-from tempest.common.utils import data_utils
+from oslo_utils import uuidutils
+from tempest.lib.common.utils import data_utils
+from tempest.lib.common.utils import test_utils
 from tempest.lib import decorators
-from tempest import test
 
 from zaqar.tests.tempest_plugin.tests import base
 
@@ -125,7 +125,7 @@ class TestSubscriptions(base.BaseV2MessagingTest):
         post_body = json.dumps(
             {'messages': [{'body': '$zaqar_message$', 'ttl': 60}]})
         post_headers = {'X-Project-ID': self.client.tenant_id,
-                        'Client-ID': str(uuid.uuid4())}
+                        'Client-ID': uuidutils.generate_uuid()}
         sub_body = {'ttl': 1200, 'subscriber': subscriber,
                     'options': {'post_data': post_body,
                                 'post_headers': post_headers}}
@@ -134,7 +134,7 @@ class TestSubscriptions(base.BaseV2MessagingTest):
         message_body = self.generate_message_body()
         self.post_messages(queue_name=self.queue_name, rbody=message_body)
 
-        if not test.call_until_true(
+        if not test_utils.call_until_true(
                 lambda: self.list_messages(sub_queue)[1]['messages'], 10, 1):
             self.fail("Couldn't get messages")
         _, body = self.list_messages(sub_queue)
