@@ -13,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
+from oslo_utils import uuidutils
 
 from tempest import config
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
-from tempest import test
 
 from zaqar.tests.tempest_plugin.tests import base
 
@@ -44,7 +43,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             results.append((resp, body))
         return results
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('0bda2907-a783-4614-af16-23d7a7d53b72')
     def test_create_subscriptions_with_invalid_body(self):
         # Missing subscriber parameter in body
@@ -58,7 +57,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('36601d23-77d5-42b1-b234-6789acdda7ba')
     def test_create_subscriptions_with_no_body(self):
         # Missing parameters in body
@@ -66,7 +65,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('1d510d93-635f-4161-b071-91f838d6907e')
     def test_create_subscriptions_with_invalid_subscriber(self):
         # The subscriber type of subscription must be supported in the list
@@ -83,7 +82,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('65be33a4-a063-47e1-b56b-9d7aa979bbcb')
     def test_create_subscriptions_with_unsupported_subscriber(self):
         # The subscriber type of subscription must be supported in the list
@@ -100,7 +99,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('cada6c25-0f59-4021-a4c3-961945913998')
     def test_create_subscriptions_with_invalid_options(self):
         # Options must be a dict
@@ -113,7 +112,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('84c1e298-c632-4ccb-859f-afe9a390081c')
     def test_create_subscriptions_with_non_integer_value_for_ttl(self):
         # The subscriber type of subscription must be supported in the list
@@ -129,7 +128,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.BadRequest,
                           self.create_subscription, self.queue_name, rbody)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('1302e137-4db6-48ad-b779-ef2095198bc2')
     def test_create_a_subscription_without_a_token(self):
         # X-Auth-Token is not provided
@@ -152,7 +151,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
 
     # List Subscriptions
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('e2109835-34ad-4f0a-8bbb-43d475d1315d')
     def test_list_subscriptions_from_non_existing_queue(self):
         # Request for listing subscriptions from a non existent queue
@@ -160,14 +159,14 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         resp, _ = self.client.list_subscription(non_existent_queue)
         self.assertEqual('200', resp['status'])
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('95d7c77f-4912-49ce-9f38-cfcc6d5cd65b')
     def test_list_subscriptions_from_queue_with_no_subsciptions(self):
         # Request to list subscription
         resp, _ = self.client.list_subscription(self.queue_name)
         self.assertEqual('200', resp['status'])
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('72f8c0b7-23d8-40ef-ae7c-212cc0751946')
     def test_list_subscription_without_a_token(self):
         # X-Auth-Token is not provided
@@ -180,7 +179,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
 
     # Show Subscriptions
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('7ecc2cb9-a0f4-4d03-b903-ecf2917fda13')
     def test_show_subscriptions_from_non_existing_queue(self):
         # Show subscription details from a non existent queue
@@ -190,7 +189,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
                           self.show_subscription, non_existent_queue,
                           invalid_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('bb46d838-e9f9-4851-a788-c30bff41c484')
     def test_show_subscriptions_with_invalid_id(self):
         # Show subscription details with invaild id
@@ -198,7 +197,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
         self.assertRaises(lib_exc.NotFound,
                           self.show_subscription, self.queue_name, invalid_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('1120f006-397a-4e8b-9e79-e2dc96b37d46')
     def test_show_subscriptions_after_deleting_subscription(self):
         # Create subscription
@@ -213,7 +212,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
                           self.show_subscription, self.queue_name,
                           subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('47a3f29f-6ddb-4cf2-87ed-a2b97733f386')
     def test_show_subscription_without_a_token(self):
         # X-Auth-Token is not provided
@@ -232,7 +231,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
 
     # Update Subscriptions
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('5c93b468-cb84-424f-af35-d4f5febc7c56')
     def test_update_subscription_on_non_existing_queue(self):
         # Update subscription on a non existing queue
@@ -247,12 +246,12 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('b383a29a-08f1-418f-8adb-c29ef080358c')
     def test_update_subscription_with_invalid_id(self):
         # Update subscription using invalid id
         results = self._create_subscriptions()
-        subscription_id = str(uuid.uuid4())
+        subscription_id = uuidutils.generate_uuid()
         update_rbody = {'ttl': 100}
         self.assertRaises(lib_exc.NotFound,
                           self.client.update_subscription, self.queue_name,
@@ -261,7 +260,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('4e446118-fa90-4f67-9a91-e157fbaa5a4c')
     def test_update_subscription_with_empty_body(self):
         # Update subscription with no body
@@ -275,7 +274,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('966f5356-9d0b-46c6-9d57-26bcd9d8e699')
     def test_update_subscription_with_invalid_TTL(self):
         # Update subscription using invalid TTL
@@ -289,7 +288,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('8838f3b2-d4c3-42e2-840c-4314e334a2f0')
     def test_update_subscription_with_invalid_json_in_request_body(self):
         # Update subscription with invalid json
@@ -303,7 +302,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('8bfe5638-0126-483e-b88a-2767fa6564e6')
     def test_update_subscription_with_invalid_token(self):
         # X-Auth-Token is not provided
@@ -323,7 +322,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
 
     # Delete Subscriptions
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('bb885255-ccac-47e1-a491-2630f205df58')
     def test_delete_subscription_from_a_non_existing_queue(self):
         # Delete subscription from a non existing queue
@@ -337,12 +336,12 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
                                                   subscription_id)
         self.assertEqual('204', resp['status'])
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('a7007b4b-1ab1-4121-9d59-afe5eb82d31c')
     def test_delete_subscription_using_a_nonexisting_id(self):
         # Delete subscription with non existent id
         results = self._create_subscriptions()
-        subscription_id = str(uuid.uuid4())
+        subscription_id = uuidutils.generate_uuid()
         resp, _ = self.client.delete_subscription(self.queue_name,
                                                   subscription_id)
         self.assertEqual('204', resp['status'])
@@ -350,7 +349,7 @@ class TestSubscriptionsNegative(base.BaseV2MessagingTest):
             subscription_id = result[1]["subscription_id"]
             self.delete_subscription(self.queue_name, subscription_id)
 
-    @test.attr(type=['negative'])
+    @decorators.attr(type=['negative'])
     @decorators.idempotent_id('8faf37ee-4abe-4586-9e4b-ed896129a3e8')
     def test_delete_subscription_with_invalid_token(self):
         # X-Auth-Token is not provided
