@@ -13,11 +13,11 @@
 # the License.
 
 import contextlib
-import uuid
 
 import ddt
 import falcon
 from oslo_serialization import jsonutils
+from oslo_utils import uuidutils
 
 from zaqar import tests as testing
 from zaqar.tests.unit.transport.wsgi import base
@@ -38,7 +38,7 @@ def pool(test, name, weight, uri, group=None, options={}):
     :returns: (name, weight, uri, options)
     :rtype: see above
     """
-    uri = "%s/%s" % (uri, str(uuid.uuid4()))
+    uri = "%s/%s" % (uri, uuidutils.generate_uuid())
     doc = {'weight': weight, 'uri': uri,
            'group': group, 'options': options}
     path = test.url_prefix + '/pools/' + name
@@ -64,12 +64,13 @@ def pools(test, count, uri, group):
     :returns: (paths, weights, uris, options)
     :rtype: ([six.text_type], [int], [six.text_type], [dict])
     """
+    mongo_url = uri
     base = test.url_prefix + '/pools/'
     args = [(base + str(i), i,
              {str(i): i})
             for i in range(count)]
     for path, weight, option in args:
-        uri = "%s/%s" % (uri, str(uuid.uuid4()))
+        uri = "%s/%s" % (mongo_url, uuidutils.generate_uuid())
         doc = {'weight': weight, 'uri': uri,
                'group': group, 'options': option}
         test.simulate_put(path, body=jsonutils.dumps(doc))
@@ -92,7 +93,7 @@ class TestPoolsMongoDB(base.V2Base):
         self.doc = {'weight': 100,
                     'group': 'mygroup',
                     'uri': self.mongodb_url}
-        self.pool = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        self.pool = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(self.pool, body=jsonutils.dumps(self.doc))
         self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
@@ -102,13 +103,13 @@ class TestPoolsMongoDB(base.V2Base):
         self.assertEqual(falcon.HTTP_204, self.srmock.status)
 
     def test_put_pool_works(self):
-        name = str(uuid.uuid1())
+        name = uuidutils.generate_uuid()
         weight, uri = self.doc['weight'], self.doc['uri']
         with pool(self, name, weight, uri, group='my-group'):
             self.assertEqual(falcon.HTTP_201, self.srmock.status)
 
     def test_put_raises_if_missing_fields(self):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(path, body=jsonutils.dumps({'weight': 100}))
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
@@ -119,7 +120,7 @@ class TestPoolsMongoDB(base.V2Base):
 
     @ddt.data(-1, 2**32+1, 'big')
     def test_put_raises_if_invalid_weight(self, weight):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         doc = {'weight': weight, 'uri': 'a'}
         self.simulate_put(path,
                           body=jsonutils.dumps(doc))
@@ -127,14 +128,14 @@ class TestPoolsMongoDB(base.V2Base):
 
     @ddt.data(-1, 2**32+1, [], 'localhost:27017')
     def test_put_raises_if_invalid_uri(self, uri):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(path,
                           body=jsonutils.dumps({'weight': 1, 'uri': uri}))
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
 
     @ddt.data(-1, 'wee', [])
     def test_put_raises_if_invalid_options(self, options):
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         doc = {'weight': 1, 'uri': 'a', 'options': options}
         self.simulate_put(path, body=jsonutils.dumps(doc))
         self.assertEqual(falcon.HTTP_400, self.srmock.status)
@@ -142,7 +143,7 @@ class TestPoolsMongoDB(base.V2Base):
     def test_put_same_database_uri(self):
         # NOTE(cabrera): setUp creates default pool
         expect = self.doc
-        path = self.url_prefix + '/pools/' + str(uuid.uuid1())
+        path = self.url_prefix + '/pools/' + uuidutils.generate_uuid()
         self.simulate_put(path, body=jsonutils.dumps(expect))
         self.assertEqual(falcon.HTTP_409, self.srmock.status)
 
