@@ -91,7 +91,7 @@ _TRANSPORT_LIMITS_GROUP = 'transport'
 
 # NOTE(kgriffs): Don't use \w because it isn't guaranteed to match
 # only ASCII characters.
-QUEUE_NAME_REGEX = re.compile('^[a-zA-Z0-9_\-]+$')
+QUEUE_NAME_REGEX = re.compile('^[a-zA-Z0-9_\-.]+$')
 QUEUE_NAME_MAX_LEN = 64
 PROJECT_ID_MAX_LEN = 256
 
@@ -121,7 +121,7 @@ class Validator(object):
 
         :param queue: Name of the queue
         :param project: Project id
-        :raises: ValidationFailed if the `name` is longer than 64
+        :raises ValidationFailed: if the `name` is longer than 64
             characters or contains anything other than ASCII digits and
             letters, underscores, and dashes.  Also raises if `project`
             is not None but longer than 256 characters.
@@ -232,6 +232,39 @@ class Validator(object):
         path_list = self._decode_json_pointer(path)
         return op, path_list
 
+    def _validate_retry_policy(self, metadata):
+        retry_policy = metadata.get('_retry_policy') if metadata else None
+        if retry_policy and not isinstance(retry_policy, dict):
+            msg = _('retry_policy must be a dict.')
+            raise ValidationFailed(msg)
+
+        if retry_policy:
+            valid_keys = ['retries_with_no_delay', 'minimum_delay_retries',
+                          'minimum_delay', 'maximum_delay',
+                          'maximum_delay_retries', 'retry_backoff_function',
+                          'ignore_subscription_override']
+            for key in valid_keys:
+                retry_value = retry_policy.get(key)
+                if key == 'retry_backoff_function':
+                    if retry_value and not isinstance(retry_value, str):
+                        msg = _('retry_backoff_function must be a string.')
+                        raise ValidationFailed(msg)
+                    # TODO(wanghao): Now we only support linear function.
+                    # This will be removed after we support more functions.
+                    if retry_value and retry_value != 'linear':
+                        msg = _('retry_backoff_function only supports linear '
+                                'now.')
+                        raise ValidationFailed(msg)
+                elif key == 'ignore_subscription_override':
+                    if retry_value and not isinstance(retry_value, bool):
+                        msg = _('ignore_subscription_override must be a '
+                                'boolean.')
+                        raise ValidationFailed(msg)
+                else:
+                    if retry_value and not isinstance(retry_value, int):
+                        msg = _('Retry policy: %s must be a integer.') % key
+                        raise ValidationFailed(msg)
+
     def queue_patching(self, request, changes):
         washed_changes = []
         content_types = {
@@ -271,7 +304,7 @@ class Validator(object):
 
         :param limit: The expected number of queues in the list
         :param kwargs: Ignored arguments passed to storage API
-        :raises: ValidationFailed if the limit is exceeded
+        :raises ValidationFailed: if the limit is exceeded
         """
 
         uplimit = self._limits_conf.max_queues_per_page
@@ -283,7 +316,7 @@ class Validator(object):
         """Restrictions on queue's length.
 
         :param content_length: Queue request's length.
-        :raises: ValidationFailed if the metadata is oversize.
+        :raises ValidationFailed: if the metadata is oversize.
         """
         if content_length is None:
             return
@@ -295,12 +328,12 @@ class Validator(object):
         """Checking if the reserved attributes of the queue are valid.
 
         :param queue_metadata: Queue's metadata.
-        :raises: ValidationFailed if any reserved attribute is invalid.
+        :raises ValidationFailed: if any reserved attribute is invalid.
         """
         if not queue_metadata:
             return
 
-        queue_default_ttl = queue_metadata.get('_default_message_ttl', None)
+        queue_default_ttl = queue_metadata.get('_default_message_ttl')
         if queue_default_ttl and not isinstance(queue_default_ttl, int):
             msg = _(u'_default_message_ttl must be integer.')
             raise ValidationFailed(msg)
@@ -327,11 +360,30 @@ class Validator(object):
                       ' and must be at least greater than 0.'),
                     self._limits_conf.max_messages_post_size)
 
+        max_claim_count = queue_metadata.get('_max_claim_count', None)
+        if max_claim_count and not isinstance(max_claim_count, int):
+            msg = _(u'_max_claim_count must be integer.')
+            raise ValidationFailed(msg)
+
+        dlq_ttl = queue_metadata.get('_dead_letter_queue_messages_ttl', None)
+        if dlq_ttl and not isinstance(dlq_ttl, int):
+            msg = _(u'_dead_letter_queue_messages_ttl must be integer.')
+            raise ValidationFailed(msg)
+
+        if dlq_ttl and not (MIN_MESSAGE_TTL <= dlq_ttl <=
+                            self._limits_conf.max_message_ttl):
+            msg = _(u'The TTL for a message may not exceed {0} seconds, '
+                    'and must be at least {1} seconds long.')
+            raise ValidationFailed(msg, self._limits_conf.max_message_ttl,
+                                   MIN_MESSAGE_TTL)
+
+        self._validate_retry_policy(queue_metadata)
+
     def queue_purging(self, document):
         """Restrictions the resource types to be purged for a queue.
 
         :param resource_types: Type list of all resource under a queue
-        :raises: ValidationFailed if the resource types are invalid
+        :raises ValidationFailed: if the resource types are invalid
         """
 
         if 'resource_types' not in document:
@@ -347,7 +399,7 @@ class Validator(object):
         """Restrictions on a list of messages.
 
         :param messages: A list of messages
-        :raises: ValidationFailed if any message has a out-of-range
+        :raises ValidationFailed: if any message has a out-of-range
             TTL.
         """
 
@@ -361,7 +413,7 @@ class Validator(object):
         """Restrictions on message post length.
 
         :param content_length: Queue request's length.
-        :raises: ValidationFailed if the metadata is oversize.
+        :raises ValidationFailed: if the metadata is oversize.
         """
         if content_length is None:
             return
@@ -407,7 +459,7 @@ class Validator(object):
 
         :param limit: The expected number of messages in the list
         :param kwargs: Ignored arguments passed to storage API
-        :raises: ValidationFailed if the limit is exceeded
+        :raises ValidationFailed: if the limit is exceeded
         """
 
         uplimit = self._limits_conf.max_messages_per_page
@@ -423,10 +475,10 @@ class Validator(object):
 
         :param ids: message ids passed in by the delete request
         :param pop: count of messages to be POPped
-        :raises: ValidationFailed if,
-                 pop AND id params are present together
-                 neither pop or id params are present
-                 message count to be popped > maximum allowed
+        :raises ValidationFailed: if,
+            pop AND id params are present together
+            neither pop or id params are present
+            message count to be popped > maximum allowed
         """
 
         if pop is not None and ids is not None:
@@ -460,7 +512,7 @@ class Validator(object):
 
         :param metadata: The claim metadata
         :param limit: The number of messages to claim
-        :raises: ValidationFailed if either TTL or grace is out of range,
+        :raises ValidationFailed: if either TTL or grace is out of range,
             or the expected number of messages exceed the limit.
         """
 
@@ -487,7 +539,7 @@ class Validator(object):
         """Restrictions on the claim TTL.
 
         :param metadata: The claim metadata
-        :raises: ValidationFailed if the TTL is out of range
+        :raises ValidationFailed: if the TTL is out of range
         """
 
         ttl = metadata['ttl']
@@ -503,7 +555,7 @@ class Validator(object):
         """Restrictions on a creation of subscription.
 
         :param subscription: dict of subscription
-        :raises: ValidationFailed if the subscription is invalid.
+        :raises ValidationFailed: if the subscription is invalid.
         """
         for p in ('subscriber',):
             if p not in subscription.keys():
@@ -515,13 +567,17 @@ class Validator(object):
         """Restrictions on an update of subscription.
 
         :param subscription: dict of subscription
-        :raises: ValidationFailed if the subscription is invalid.
+        :raises ValidationFailed: if the subscription is invalid.
         """
 
         if not subscription:
             raise ValidationFailed(_(u'No subscription to create.'))
 
-        subscriber = subscription.get('subscriber', None)
+        if not isinstance(subscription, dict):
+            msg = _('Subscriptions must be a dict.')
+            raise ValidationFailed(msg)
+
+        subscriber = subscription.get('subscriber')
         subscriber_type = None
 
         if subscriber:
@@ -533,12 +589,14 @@ class Validator(object):
                         u'supported in the list {0}.')
                 raise ValidationFailed(msg, self._limits_conf.subscriber_types)
 
-        options = subscription.get('options', None)
+        options = subscription.get('options')
         if options and not isinstance(options, dict):
             msg = _(u'Options must be a dict.')
             raise ValidationFailed(msg)
 
-        ttl = subscription.get('ttl', None)
+        self._validate_retry_policy(options)
+
+        ttl = subscription.get('ttl')
         if ttl:
             if not isinstance(ttl, int):
                 msg = _(u'TTL must be an integer.')
@@ -564,7 +622,7 @@ class Validator(object):
                 raise ValidationFailed(msg, datetime.datetime.max)
 
     def subscription_confirming(self, confirmed):
-        confirmed = confirmed.get('confirmed', None)
+        confirmed = confirmed.get('confirmed')
         if not isinstance(confirmed, bool):
             msg = _(u"The 'confirmed' should be boolean.")
             raise ValidationFailed(msg)
@@ -574,7 +632,7 @@ class Validator(object):
 
         :param limit: The expected number of subscriptions in the list
         :param kwargs: Ignored arguments passed to storage API
-        :raises: ValidationFailed if the limit is exceeded
+        :raises ValidationFailed: if the limit is exceeded
         """
 
         uplimit = self._limits_conf.max_subscriptions_per_page
@@ -597,7 +655,7 @@ class Validator(object):
 
         :param limit: The expected number of flavors in the list
         :param kwargs: Ignored arguments passed to storage API
-        :raises: ValidationFailed if the limit is exceeded
+        :raises ValidationFailed: if the limit is exceeded
         """
 
         uplimit = self._limits_conf.max_flavors_per_page
@@ -610,7 +668,7 @@ class Validator(object):
 
         :param limit: The expected number of flavors in the list
         :param kwargs: Ignored arguments passed to storage API
-        :raises: ValidationFailed if the limit is exceeded
+        :raises ValidationFailed: if the limit is exceeded
         """
 
         uplimit = self._limits_conf.max_pools_per_page
