@@ -17,6 +17,7 @@ import falcon
 from oslo_log import log as logging
 import six
 
+from zaqar.common import decorators
 from zaqar.common.transport.wsgi import helpers as wsgi_helpers
 from zaqar.i18n import _
 from zaqar.storage import errors as storage_errors
@@ -37,6 +38,7 @@ class CollectionResource(object):
         '_wsgi_conf',
         '_validate',
         '_message_post_spec',
+        '_default_message_ttl'
     )
 
     def __init__(self, wsgi_conf, validate,
@@ -47,9 +49,10 @@ class CollectionResource(object):
         self._validate = validate
         self._message_controller = message_controller
         self._queue_controller = queue_controller
+        self._default_message_ttl = default_message_ttl
 
         self._message_post_spec = (
-            ('ttl', int, default_message_ttl),
+            ('ttl', int, self._default_message_ttl),
             ('body', '*', None),
         )
 
@@ -150,17 +153,40 @@ class CollectionResource(object):
     # Interface
     # ----------------------------------------------------------------------
 
+    @decorators.TransportLog("Messages collection")
     @acl.enforce("messages:create")
     def on_post(self, req, resp, project_id, queue_name):
-        LOG.debug(u'Messages collection POST - queue:  %(queue)s, '
-                  u'project: %(project)s',
-                  {'queue': queue_name, 'project': project_id})
-
         client_uuid = wsgi_helpers.get_client_uuid(req)
-
         try:
+            # NOTE(flwang): Replace 'exists' with 'get_metadata' won't impact
+            # the performance since both of them will call
+            # collection.find_one()
+            queue_meta = None
+            try:
+                queue_meta = self._queue_controller.get_metadata(queue_name,
+                                                                 project_id)
+            except storage_errors.DoesNotExist as ex:
+                self._validate.queue_identification(queue_name, project_id)
+                self._queue_controller.create(queue_name, project=project_id)
+                # NOTE(flwang): Queue is created in lazy mode, so no metadata
+                # set.
+                queue_meta = {}
+
+            queue_max_msg_size = queue_meta.get('_max_messages_post_size')
+            queue_default_ttl = queue_meta.get('_default_message_ttl')
+
+            # TODO(flwang): To avoid any unexpected regression issue, we just
+            # leave the _message_post_spec attribute of class as it's. It
+            # should be removed in Newton release.
+            if queue_default_ttl:
+                message_post_spec = (('ttl', int, queue_default_ttl),
+                                     ('body', '*', None),)
+            else:
+                message_post_spec = (('ttl', int, self._default_message_ttl),
+                                     ('body', '*', None),)
             # Place JSON size restriction before parsing
-            self._validate.message_length(req.content_length)
+            self._validate.message_length(req.content_length,
+                                          max_msg_post_size=queue_max_msg_size)
         except validation.ValidationFailed as ex:
             LOG.debug(ex)
             raise wsgi_errors.HTTPBadRequestAPI(six.text_type(ex))
@@ -173,15 +199,12 @@ class CollectionResource(object):
             raise wsgi_errors.HTTPBadRequestAPI(description)
 
         messages = wsgi_utils.sanitize(document['messages'],
-                                       self._message_post_spec,
+                                       message_post_spec,
                                        doctype=wsgi_utils.JSONArray)
 
         try:
             self._validate.message_posting(messages)
 
-            if not self._queue_controller.exists(queue_name, project_id):
-                self._queue_controller.create(queue_name, project=project_id)
-
             message_ids = self._message_controller.post(
                 queue_name,
                 messages=messages,
@@ -194,7 +217,7 @@ class CollectionResource(object):
 
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            raise falcon.HTTPNotFound()
+            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
 
         except storage_errors.MessageConflict as ex:
             LOG.exception(ex)
@@ -215,12 +238,9 @@ class CollectionResource(object):
         resp.body = utils.to_json(body)
         resp.status = falcon.HTTP_201
 
+    @decorators.TransportLog("Messages collection")
     @acl.enforce("messages:get_all")
     def on_get(self, req, resp, project_id, queue_name):
-        LOG.debug(u'Messages collection GET - queue: %(queue)s, '
-                  u'project: %(project)s',
-                  {'queue': queue_name, 'project': project_id})
-
         ids = req.get_param_as_list('ids')
 
         if ids is None:
@@ -234,18 +254,19 @@ class CollectionResource(object):
             # NOTE(TheSriram): Trying to get a message by id, should
             # return the message if its present, otherwise a 404 since
             # the message might have been deleted.
-            resp.status = falcon.HTTP_404
+            msg = _(u'No messages with IDs: {ids} found in the queue {queue} '
+                    u'for project {project}.')
+            description = msg.format(queue=queue_name, project=project_id,
+                                     ids=ids)
+            raise wsgi_errors.HTTPNotFound(description)
 
         else:
             resp.body = utils.to_json(response)
         # status defaults to 200
 
+    @decorators.TransportLog("Messages collection")
     @acl.enforce("messages:delete_all")
     def on_delete(self, req, resp, project_id, queue_name):
-        LOG.debug(u'Messages collection DELETE - queue: %(queue)s, '
-                  u'project: %(project)s',
-                  {'queue': queue_name, 'project': project_id})
-
         ids = req.get_param_as_list('ids')
         pop_limit = req.get_param_as_int('pop')
         try:
@@ -310,13 +331,9 @@ class ItemResource(object):
     def __init__(self, message_controller):
         self._message_controller = message_controller
 
+    @decorators.TransportLog("Messages item")
     @acl.enforce("messages:get")
     def on_get(self, req, resp, project_id, queue_name, message_id):
-        LOG.debug(u'Messages item GET - message: %(message)s, '
-                  u'queue: %(queue)s, project: %(project)s',
-                  {'message': message_id,
-                   'queue': queue_name,
-                   'project': project_id})
         try:
             message = self._message_controller.get(
                 queue_name,
@@ -325,7 +342,7 @@ class ItemResource(object):
 
         except storage_errors.DoesNotExist as ex:
             LOG.debug(ex)
-            raise falcon.HTTPNotFound()
+            raise wsgi_errors.HTTPNotFound(six.text_type(ex))
 
         except Exception as ex:
             LOG.exception(ex)
@@ -341,15 +358,9 @@ class ItemResource(object):
         resp.body = utils.to_json(message)
         # status defaults to 200
 
+    @decorators.TransportLog("Messages item")
     @acl.enforce("messages:delete")
     def on_delete(self, req, resp, project_id, queue_name, message_id):
-
-        LOG.debug(u'Messages item DELETE - message: %(message)s, '
-                  u'queue: %(queue)s, project: %(project)s',
-                  {'message': message_id,
-                   'queue': queue_name,
-                   'project': project_id})
-
         error_title = _(u'Unable to delete')
 
         try:
